==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/content/messages/el/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Επίσης ορατό σε μη μέλη του χώρου)',
    '<strong>Confirm</strong> post deletion' => '<strong>Επιβεβαίωση</strong> διαγραφή ανάρτησης',
    '<strong>Move</strong> content' => '<strong>Μετακίνηση</strong> περιεχομένου',
    '<strong>Permalink</strong> to this post' => '<strong>Mόνιμος σύνδεσμος </strong> σε αυτή τη θέση',
    'Activated' => 'Ενεργοποιήθηκε',
    'Add a member to notify' => 'Προσθέστε ένα μέλος για ειδοποίηση',
    'Add tag...' => 'Προσθήκη ετικέτας...',
    'Archived' => 'Αρχειοθετημένα',
    'Attach Files' => 'Επισύναψη Αρχείων',
    'Back to stream' => 'Πίσω στη ροή',
    'Cancel' => 'Ακύρωση',
    'Cancel Edit' => 'Ακύρωση επεξεργασίας',
    'Change to "Private"' => 'Αλλαγή σε ιδιωτικό',
    'Change to "Public"' => 'Αλλαγή σε δημόσιο',
    'Configure' => 'Ρύθμιση',
    'Confirm' => 'Επιβεβαίωση',
    'Content' => 'Περιεχόμενο',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Ετικέτα περιεχομένου με μη έγκυρο contentcontainer_id έχει εκχωρηθεί.',
    'Content has been moved to {spacename}' => 'Το περιεχόμενο μεταφέρθηκε στο {spacename}',
    'Could not find requested content!' => 'Δεν ήταν δυνατή η εύρεση του περιεχομένου που ζητήθηκε!',
    'Created at:' => 'Δημιουργήθηκε στις:',
    'Created by me' => 'Δημιουργήθηκε από εμένα',
    'Creation time' => 'Ώρα δημιουργίας',
    'Delete' => 'Διαγραφή',
    'Do you really want to delete this post? All likes and comments will be lost!' => 'Θέλετε πραγματικά να διαγράψετε αυτήν την ανάρτηση; Όλα τα μου αρέσει και σχόλια θα χαθούν!',
    'Edit' => 'Επεξεργασία',
    'Enable' => 'Ενεργοποίηση',
    'Filter' => 'Φίλτρο',
    'I\'m involved' => 'Πού συμμετέχω;',
    'Invalid content id given!' => 'Μη έγκυρο αναγνωριστικό ID περιεχομένου!',
    'Invalid request method!' => 'Μη έγκυρη μέθοδος αίτησης!',
    'Invalid space selection.' => 'Μη έγκυρη επιλογή χώρου.',
    'Last update' => 'Τελευταία ενημέρωση',
    'Last updated {time}' => 'Τελευταία ενημέρωση {time}',
    'Load more' => 'Φόρτωσε περισσότερα',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Μέγιστος αριθμός καρφιτσωμένων αντικειμένων! <br>Μπορείτε να καρφιτσώσετε έως {count} αντικείμενα ταυτόχρονα.',
    'Move content' => 'Μετακίνηση περιεχομένου',
    'Move to archive' => 'Μετακίνηση στην αρχειοθέτηση',
    'No matches with your selected filters!' => 'Δεν υπάρχουν αντιστοιχίες με τα επιλεγμένα φίλτρα σας!',
    'No tags found for the given query' => 'Δεν βρέθηκαν ετικέτες για την συγκεκριμένη αναζήτηση',
    'None' => 'Κανένα',
    'Nothing here yet!' => 'Δεν υπάρχει τίποτα ακόμα!',
    'Notify members' => 'Ειδοποίηση μελών',
    'Permalink' => 'Mόνιμη σύνδεση',
    'Pin to top' => 'Καρφίτσωμα στην κορυφή',
    'Pinned' => 'Καρφιτσαρισμένο',
    'Private' => 'Ιδιωτικό',
    'Public' => 'Δημόσιο',
    'Select type...' => 'Επιλέξτε τύπο...',
    'Specify who can see this content.' => 'Δηλώστε ποιός μπορεί να δει το περιεχόμενο αυτό.',
    'Submit' => 'Υποβολή',
    'Tag' => 'Ετικέτα',
    'Target Space' => 'Στόχευση χώρου',
    'The author of this content is not allowed to create private content within the selected space.' => 'Ο συγγραφέας αυτού του περιεχομένου δεν επιτρέπεται να δημιουργήσει ιδιωτικό περιεχόμενο εντός του επιλεγμένου χώρου.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Ο συντάκτης αυτού του περιεχομένου δεν επιτρέπεται να δημιουργεί δημόσιο περιεχόμενο εντός του επιλεγμένου χώρου.',
    'The author of this content is not allowed to create this type of content within this space.' => 'Ο συγγραφέας του περιεχομένου δεν επιτρέπεται να δημιουργήσει αυτό τον τύπο περιεχομένου σε αυτό τον χώρο.',
    'The content can\'t be moved to its current space.' => 'Το περιεχόμενο δεν μπορεί να μετακινηθεί στον τρέχοντα χώρο.',
    'The content has been archived.' => 'Το περιεχόμενο έχει αρχειοθετηθεί.',
    'The content has been deleted.' => 'Το περιεχόμενο έχει διαγραφεί.',
    'The content has been unarchived.' => 'Το περιεχόμενο βγήκε απο την αρχειοθετηση.',
    'The given name is already in use.' => 'Το όνομα χρησιμοποιείται ήδη.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Η ενότητα {moduleName} δεν είναι ενεργοποιημένη στον επιλεγμένο στοχευμένο χώρο.',
    'This action is disabled!' => 'Αυτή η ενέργεια είναι απενεργοποιημένη!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Αυτός ο τύπος περιεχομένου δεν μπορεί να μετακινηθεί λόγω ρύθμισης id-module που λείπει.',
    'This content type can\'t be moved.' => 'Αυτός ο τύπος περιεχομένου δεν μπορεί να μετακινηθεί.',
    'This space is archived.' => 'Αυτός ο χώρος είναι αρχειοθετημένος.',
    'This space is not visible!' => 'Αυτός ο χώρος δεν είναι ορατός!',
    'Topics' => 'Θέματα',
    'Turn off notifications' => 'Απενεργοποίηση ειδοποιήσεων',
    'Turn on notifications' => 'Ενεργοποίηση ειδοποιήσεων',
    'Unarchive' => 'Χωρίς αρχειοθέτηση',
    'Unpin' => 'Ξεκαρφίτσωμα',
    'Updated' => 'Ενημερωμένο',
    'Visible also to unregistered users' => 'Ορατό και σε χρήστες που δεν έχουν εγγραφεί',
    'Visible only to you' => 'Ορατό μόνο σε εσάς',
    'Visible to all Space members' => 'Ορατό σε όλα τα μέλη του χώρου',
    'Visible to all signed in users' => 'Ορατό σε όλους τους χρήστες που έχουν εισέλθει',
    'Visible to friends of {displayName}' => 'Ορατό στους φίλους του/της {displayName}',
    'Visible to you and {displayName}' => 'Ορατό σε εσάς και στον/στην {displayName}',
    'Visible to your friends' => 'Ορατό στους φίλους σας',
    'With attachments' => 'Με συνημμένα αρχεία',
    'You do not have the permission to move this content to the given space.' => 'Δεν έχετε την άδεια να μετακινήσετε αυτό το περιεχόμενο στον συγκεκριμένο χώρο.',
    'You do not have the permission to move this content.' => 'Δεν έχετε την άδεια να μετακινήσετε αυτό το περιεχόμενο.',
    'Your last edit state has been saved!' => 'Η τελευταία κατάσταση επεξεργασίας έχει αποθηκευτεί!',
    'in' => 'σε',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Create as draft' => '',
    'Deleted' => '',
    'Draft' => '',
    'Hidden' => '',
    'Lock comments' => '',
    'New Updates Available!' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Schedule publication' => '',
    'Scheduled at {dateTime}' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/content/messages/el/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Επίσης ορατό σε μη μέλη του χώρου)',
    '<strong>Move</strong> content' => '<strong>Μετακίνηση</strong> περιεχομένου',
    '<strong>Permalink</strong> to this post' => '<strong>Mόνιμος σύνδεσμος </strong> σε αυτή τη θέση',
    'Activated' => 'Ενεργοποιήθηκε',
    'Add a member to notify' => 'Προσθέστε ένα μέλος για ειδοποίηση',
    'Add tag...' => 'Προσθήκη ετικέτας...',
    'Archived' => 'Αρχειοθετημένα',
    'Attach Files' => 'Επισύναψη Αρχείων',
    'Back to stream' => 'Πίσω στη ροή',
    'Cancel' => 'Ακύρωση',
    'Cancel Edit' => 'Ακύρωση επεξεργασίας',
    'Change to "Private"' => 'Αλλαγή σε ιδιωτικό',
    'Change to "Public"' => 'Αλλαγή σε δημόσιο',
    'Configure' => 'Ρύθμιση',
    'Confirm' => 'Επιβεβαίωση',
    'Content' => 'Περιεχόμενο',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Ετικέτα περιεχομένου με μη έγκυρο contentcontainer_id έχει εκχωρηθεί.',
    'Content has been moved to {spacename}' => 'Το περιεχόμενο μεταφέρθηκε στο {spacename}',
    'Could not find requested content!' => 'Δεν ήταν δυνατή η εύρεση του περιεχομένου που ζητήθηκε!',
    'Created at:' => 'Δημιουργήθηκε στις:',
    'Created by me' => 'Δημιουργήθηκε από εμένα',
    'Creation time' => 'Ώρα δημιουργίας',
    'Delete' => 'Διαγραφή',
    'Edit' => 'Επεξεργασία',
    'Enable' => 'Ενεργοποίηση',
    'Filter' => 'Φίλτρο',
    'I\'m involved' => 'Πού συμμετέχω;',
    'Invalid content id given!' => 'Μη έγκυρο αναγνωριστικό ID περιεχομένου!',
    'Invalid request method!' => 'Μη έγκυρη μέθοδος αίτησης!',
    'Invalid space selection.' => 'Μη έγκυρη επιλογή χώρου.',
    'Last update' => 'Τελευταία ενημέρωση',
    'Last updated {time}' => 'Τελευταία ενημέρωση {time}',
    'Load more' => 'Φόρτωσε περισσότερα',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Μέγιστος αριθμός καρφιτσωμένων αντικειμένων! <br>Μπορείτε να καρφιτσώσετε έως {count} αντικείμενα ταυτόχρονα.',
    'Move content' => 'Μετακίνηση περιεχομένου',
    'Move to archive' => 'Μετακίνηση στην αρχειοθέτηση',
    'No matches with your selected filters!' => 'Δεν υπάρχουν αντιστοιχίες με τα επιλεγμένα φίλτρα σας!',
    'No tags found for the given query' => 'Δεν βρέθηκαν ετικέτες για την συγκεκριμένη αναζήτηση',
    'None' => 'Κανένα',
    'Nothing here yet!' => 'Δεν υπάρχει τίποτα ακόμα!',
    'Notify members' => 'Ειδοποίηση μελών',
    'Permalink' => 'Mόνιμη σύνδεση',
    'Pin to top' => 'Καρφίτσωμα στην κορυφή',
    'Pinned' => 'Καρφιτσαρισμένο',
    'Private' => 'Ιδιωτικό',
    'Public' => 'Δημόσιο',
    'Select type...' => 'Επιλέξτε τύπο...',
    'Specify who can see this content.' => 'Δηλώστε ποιός μπορεί να δει το περιεχόμενο αυτό.',
    'Submit' => 'Υποβολή',
    'Tag' => 'Ετικέτα',
    'Target Space' => 'Στόχευση χώρου',
    'The author of this content is not allowed to create private content within the selected space.' => 'Ο συγγραφέας αυτού του περιεχομένου δεν επιτρέπεται να δημιουργήσει ιδιωτικό περιεχόμενο εντός του επιλεγμένου χώρου.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Ο συντάκτης αυτού του περιεχομένου δεν επιτρέπεται να δημιουργεί δημόσιο περιεχόμενο εντός του επιλεγμένου χώρου.',
    'The author of this content is not allowed to create this type of content within this space.' => 'Ο συγγραφέας του περιεχομένου δεν επιτρέπεται να δημιουργήσει αυτό τον τύπο περιεχομένου σε αυτό τον χώρο.',
    'The content can\'t be moved to its current space.' => 'Το περιεχόμενο δεν μπορεί να μετακινηθεί στον τρέχοντα χώρο.',
    'The content has been archived.' => 'Το περιεχόμενο έχει αρχειοθετηθεί.',
    'The content has been deleted.' => 'Το περιεχόμενο έχει διαγραφεί.',
    'The content has been unarchived.' => 'Το περιεχόμενο βγήκε απο την αρχειοθετηση.',
    'The given name is already in use.' => 'Το όνομα χρησιμοποιείται ήδη.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Η ενότητα {moduleName} δεν είναι ενεργοποιημένη στον επιλεγμένο στοχευμένο χώρο.',
    'This action is disabled!' => 'Αυτή η ενέργεια είναι απενεργοποιημένη!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Αυτός ο τύπος περιεχομένου δεν μπορεί να μετακινηθεί λόγω ρύθμισης id-module που λείπει.',
    'This content type can\'t be moved.' => 'Αυτός ο τύπος περιεχομένου δεν μπορεί να μετακινηθεί.',
    'This space is archived.' => 'Αυτός ο χώρος είναι αρχειοθετημένος.',
    'This space is not visible!' => 'Αυτός ο χώρος δεν είναι ορατός!',
    'Topics' => 'Θέματα',
    'Turn off notifications' => 'Απενεργοποίηση ειδοποιήσεων',
    'Turn on notifications' => 'Ενεργοποίηση ειδοποιήσεων',
    'Unarchive' => 'Χωρίς αρχειοθέτηση',
    'Unpin' => 'Ξεκαρφίτσωμα',
    'Updated' => 'Ενημερωμένο',
    'Visible also to unregistered users' => 'Ορατό και σε χρήστες που δεν έχουν εγγραφεί',
    'Visible only to you' => 'Ορατό μόνο σε εσάς',
    'Visible to all Space members' => 'Ορατό σε όλα τα μέλη του χώρου',
    'Visible to all signed in users' => 'Ορατό σε όλους τους χρήστες που έχουν εισέλθει',
    'Visible to friends of {displayName}' => 'Ορατό στους φίλους του/της {displayName}',
    'Visible to you and {displayName}' => 'Ορατό σε εσάς και στον/στην {displayName}',
    'Visible to your friends' => 'Ορατό στους φίλους σας',
    'With attachments' => 'Με συνημμένα αρχεία',
    'You do not have the permission to move this content to the given space.' => 'Δεν έχετε την άδεια να μετακινήσετε αυτό το περιεχόμενο στον συγκεκριμένο χώρο.',
    'You do not have the permission to move this content.' => 'Δεν έχετε την άδεια να μετακινήσετε αυτό το περιεχόμενο.',
    'Your last edit state has been saved!' => 'Η τελευταία κατάσταση επεξεργασίας έχει αποθηκευτεί!',
    'in' => 'σε',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Create as draft' => '',
    'Deleted' => '',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '',
    'Draft' => '',
    'Hidden' => '',
    'Lock comments' => '',
    'New Updates Available!' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Save as draft' => '',
    'Save scheduling' => '',
    'Schedule publication' => '',
    'Scheduled for {dateTime}' => '',
    'The content cannot be published!' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];
